@@ -432,7 +432,7 @@ class Vm(object):
         Need to addition for each VM the size of each disks in bytes
         """
         log.info('Enter with vmpath={}'.format(vmpath))
-        cmd="for i in `virsh list | awk '{print $2}'`: do file "+vmpath+"/$i/* ; done"
+        cmd="for i in `virsh list --all | awk '{print $2}'`; do file "+vmpath+"/$i/* ; done"
         self.ssh.shell_send([cmd+"\n"])
         for line in self.ssh.output.splitlines():
             log.debug("line={}".format(line))
@@ -457,7 +457,7 @@ class Vm(object):
                     self._vms_disks_dict[id] = int(size)
                 else:
                     self._vms_disks_dict[id] = int(self._vms_disks_dict[id]) + int(size)
-                log.debug("XXX id={} size={} total={} ".format(id, size, self._vms_disks_dict[id] ))
+                log.debug("id={} size={} total={} ".format(id, size, self._vms_disks_dict[id] ))
 
     def dump_statistics(self):
         """
